<?php
	# Mantis - a php based bugtracking system
	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
	# This program is distributed under the terms and conditions of the GPL
	# See the README and LICENSE files for details

	# CALLERS
	#	This page is called from:
	#	- header redirects from account_*.php

	# EXPECTED BEHAVIOUR
	#	- Display the list of custom My View Filters
	#	- Allow the user to add/remove/re-sequence filters in My View

	# CALLS
	#	This page calls the following pages:
	#	- account_my_view_add.php  		(to add a new filter)
	#	- account_my_view_delete.php  	(to delete a filter from my view)
	#	- account_my_view_sequence.php  (to change the sequence of the filters)

	# RESTRICTIONS & PERMISSIONS
	#	- User must be authenticated
	#	- The user's account must not be protected
	#	- The user must be above the "Custom My View" threshold

	require_once( 'core.php' );

	$t_core_path = config_get( 'core_path' );
	require_once( $t_core_path.'current_user_api.php' );
	require_once( $t_core_path.'filter_api.php' );

	auth_ensure_user_authenticated();

	current_user_ensure_unprotected();

	access_ensure_global_level( config_get('custom_my_view_threshold' ) );


	html_page_top1( lang_get( 'my_view_filters' ) );
	html_page_top2();

	$p_user_id = auth_get_current_user_id();
?>
<br />
<div align="center">
<table class="width75" cellspacing="1">

	<!-- Headings -->
	<tr>
		<td class="form-title">
			<?php echo lang_get( 'my_view_filters' ) ?>
		</td>
		<td class="right" colspan='3'>
			<?php print_account_menu( 'account_my_view_page.php' ) ?>
		</td>
	</tr>

	<tr>
		<td class="category">
			<?php echo lang_get( 'custom_filters' ) ?>
		</td>
		<td class="category center">
			<?php echo lang_get( 'projects_link' ) ?>
		</td>
		<td class="category center">
			<?php echo lang_get( 'custom_field_sequence' ) ?>
		</td>
		<td class="category center">
			<?php echo lang_get( 'actions' ) ?>
		</td>
	</tr>
<?php

$t_active_filters = filter_db_get_my_view($p_user_id);

$i = 0;

foreach ($t_active_filters AS $filter) {

	$i++;

	?>
	<tr <?php echo helper_alternate_class() ?>>
		<td class="left">
			<?php echo string_display($filter['name']); ?>
		</td>
		<td class="center">
			<?php echo string_display(project_get_name( $filter['project_id'] )) ?>
		</td>
		<td class="center">
			<?php
				if ($i != 1)
					print_button( 'account_my_view_sequence.php?move=1&filter_id=' . $filter['id'], "^" );
				if ($i < count($t_active_filters))
					print_button( 'account_my_view_sequence.php?move=0&filter_id=' . $filter['id'], "v" );
			?>
		</td>
		<td class="center">
			<?php print_button( 'account_my_view_delete.php?filter_id=' . $filter['id'], lang_get( 'delete_link' ) ); ?>
		</td>
	</tr>
	<?php
}

?>
	<!-- BUTTONS -->
	<tr>
		<td class="left" colspan="3">
			<?php print_filter_my_view_inactive( FALSE ) ?>
			<?php print_button( 'query_view_page.php', lang_get( 'open_queries' ) ); ?>
		</td>
	</tr>
</table>
</div>


<?php html_page_bottom1( __FILE__ ) ?>